package
Version:
v0.1.4
Opens a new window with list of versions in this module.
Published: May 3, 2026
License: MIT
Opens a new window with license information.
Imports: 15
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Options struct {
AuthToken string
}
Options configures the web dashboard server.
Server is the HTTP server for the web dashboard.
NewServer creates a new web server listening on addr (e.g. "127.0.0.1:20021").
Shutdown gracefully stops the server.
Start starts the HTTP server. Blocks until the server exits.
WSHub manages WebSocket client connections.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.